# Script to enable indexing of OneNote and Microsoft Publisher filtering in Exchange 2013
# Written by Brian Reid, C7 Solutions Ltd. www.c7solutions.com 14:27 21/11/2012
# Based on a script by Mark Smith from Capex Global that installed PDF filtering for Exch2010
# Note PDF filtering is included in Exchange 2013 and not needed as an extra install

# The Microsoft Office 2010 Filter Pack needs installing before running this script: http://www.microsoft.com/en-us/download/details.aspx?id=17062
# The Microsoft Office 2010 Filter Pack SP1 (x64) needs installing before running this script: http://www.microsoft.com/en-us/download/details.aspx?id=26604
# This script has not been tested with the Microsoft Office Filter Pack 2013 release as it was not available at time of writing

# This script will restart the Transport service and Microsoft Filtering Management Service. Mail-flow might be affected
# by the first of these restarts. Existing items in the store will not be indexed 

$iFilterDirName = "C:\Program Files\Common Files\Microsoft Shared\Filters\"
 
$KeyParent = "HKLM:\SOFTWARE\Microsoft\ExchangeServer\v15\HubTransportRole"
$CLSIDKey = "HKLM:\SOFTWARE\Microsoft\ExchangeServer\v15\HubTransportRole\CLSID"
$FiltersKey = "HKLM:\SOFTWARE\Microsoft\ExchangeServer\v15\HubTransportRole\filters"
 
# Filter DLL Locations
$ONEFilterLocation = $iFilterDirName + "\ONIFilter.dll"
$PUBFilterLocation = $iFilterDirName + "\PUBFILT.dll"
 
# Filter GUIDs
$ONEGuid    ="{B8D12492-CE0F-40AD-83EA-099A03D493F1}"
$PUBGuid    ="{A7FD8AC9-7ABF-46FC-B70B-6A5E5EC9859A}"
 

# Create CLSID and filters root registry keys if they do not exist
Write-Host -foregroundcolor Green "Creating parent registry keys"

New-Item -Path $KeyParent -Name CLSID -ErrorAction SilentlyContinue | Out-Null
New-Item -Path $KeyParent -Name filters -ErrorAction SilentlyContinue | Out-Null


# Create CLSIDs
Write-Host -foregroundcolor Green "Creating CLSIDs..."
 
New-Item -Path $CLSIDKey -Name $ONEGuid -Value $ONEFilterLocation -Type String | Out-Null
New-Item -Path $CLSIDKey -Name $PUBGuid -Value $PUBFilterLocation -Type String | Out-Null
 
# Set Threading model
Write-Host -foregroundcolor Green "Setting threading model..."
 
New-ItemProperty -Path "$CLSIDKey\$ONEGuid" -Name "ThreadingModel" -Value "Both" -Type String | Out-Null
New-ItemProperty -Path "$CLSIDKey\$PUBGuid" -Name "ThreadingModel" -Value "Both" -Type String | Out-Null
 
# Set Flags
Write-Host -foregroundcolor Green "Setting Flags..."
New-ItemProperty -Path "$CLSIDKey\$ONEGuid" -Name "Flags" -Value "1" -Type Dword | Out-Null
New-ItemProperty -Path "$CLSIDKey\$PUBGuid" -Name "Flags" -Value "1" -Type Dword | Out-Null
 
# Create Filter Entries
Write-Host -foregroundcolor Green "Creating Filter Entries..."
 
New-Item -Path $FiltersKey -Name ".one" -Value $ONEGuid -Type String | Out-Null
New-Item -Path $FiltersKey -Name ".pub" -Value $PUBGuid -Type String | Out-Null

# Setting permissions
Write-Host -foregroundcolor Green "Granting NETWORK SERVICE read access to $KeyParent and child keys "
$acl = Get-Acl $KeyParent
$rule = New-Object System.Security.AccessControl.RegistryAccessRule ("NETWORK SERVICE","ReadKey","Allow")
$acl.SetAccessRule($rule)
$acl | Set-Acl -Path $KeyParent 

# Restarting required services
Write-Host -foregroundcolor Green "Stopping Microsoft Exchange Transport service (this takes a few minutes)"
Stop-Service "Microsoft Exchange Transport" | Out-Null
Write-Host -foregroundcolor Green "Stopping Microsoft Filtering Management Service"
Stop-Service "Microsoft Filtering Management Service" | Out-Null
Write-Host -foregroundcolor Green "Starting Microsoft Exchange Transport service (this takes a few minutes)"
Start-Service "Microsoft Exchange Transport" | Out-Null
Write-Host -foregroundcolor Green "Starting Microsoft Filtering Management Service"
Start-Service "Microsoft Filtering Management Service" | Out-Null


